# Django UK Geo Utils

Django app for working with OS AddressBase, ONSUD and ONSPD

---

[![Build Status](https://travis-ci.org/DemocracyClub/uk-geo-utils.svg?branch=master)](https://travis-ci.org/DemocracyClub/uk-geo-utils)
[![Coverage Status](https://coveralls.io/repos/github/DemocracyClub/uk-geo-utils/badge.svg?branch=master)](https://coveralls.io/github/DemocracyClub/uk-geo-utils?branch=master)
![PyPI Version](https://img.shields.io/pypi/v/uk-geo-utils.svg)
![License](https://img.shields.io/pypi/l/uk-geo-utils.svg)
![Python Support](https://img.shields.io/pypi/pyversions/uk-geo-utils.svg)
![Django Support](https://img.shields.io/pypi/djversions/uk-geo-utils.svg)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)


* [Documentation](https://democracyclub.github.io/uk-geo-utils/)
* [Support](https://github.com/DemocracyClub/uk-geo-utils/issues)
* [Code of Conduct](https://democracyclub.org.uk/code-of-conduct/)
